﻿using AutoMapper;
using OASystem.Domain;
using OASystem.Domain.Dtos.Resource;
using OASystem.Domain.Entities.Resource;
using OASystem.Domain.ViewModels.Resource;

namespace OASystem.Infrastructure.Repositories.Resource
{
    public class CarDataRepository: BaseRepository<Res_CarData, CarDataView>
    {
        private readonly IMapper _mapper;
        public CarDataRepository(SqlSugarClient sqlSugar, IMapper mapper) : base(sqlSugar)
        {
            _mapper = mapper;
        }

        /// <summary>
        /// 查询用车资料
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task<Result> QueryCarData(QueryCarDataDto dto)
        {
            Result result = new Result() { Code = -2, Msg = "未知错误" };
            try
            {
                string sqlWhere = string.Empty;
                if (!string.IsNullOrWhiteSpace(dto.UnitName))
                {
                    sqlWhere += string.Format(@" And UnitName like '%{0}%'", dto.UnitName);
                }
                if (!string.IsNullOrWhiteSpace(dto.UnitArea) && dto.UnitArea!="全部")
                {
                    sqlWhere += string.Format(@" And UnitArea like '%{0}%'", dto.UnitArea);
                }
                if (!string.IsNullOrWhiteSpace(dto.Contact))
                {
                    sqlWhere += string.Format(@" And Contact like '%{0}%'", dto.Contact);
                }
                if (!string.IsNullOrWhiteSpace(dto.ContactTel))
                {
                    sqlWhere += string.Format(@" And ContactTel like '%{0}%'", dto.ContactTel);
                }
                if (!string.IsNullOrEmpty(sqlWhere.Trim()))
                {
                    Regex r = new Regex("And");
                    sqlWhere = r.Replace(sqlWhere, "Where", 1);
                }
                if (dto.PortType == 1)
                {
                    string sql = string.Format(@"select * from Res_CarData {0}", sqlWhere);
                    List<Res_CarData> CarData = await _sqlSugar.SqlQueryable<Res_CarData>(sql).ToListAsync();
                    if (CarData.Count==0)
                    {
                        return result = new Result() { Code = -1, Msg = "暂无数据" };
                    }
                    CarData= CarData.OrderByDescending(x => x.CreateTime).ToList();

                    if (dto.PageSize==0 && dto.PageIndex==0)
                    {
                        return result = new Result()
                        {
                            Code = 0,
                            Msg = "查询成功",
                            Data = CarData,
                        };
                    }
                    else
                    {
                        int count = CarData.Count;
                        float totalPage = (float)count / dto.PageSize;//总页数
                        if (totalPage == 0) totalPage = 1;
                        else totalPage = (int)Math.Ceiling((double)totalPage);

                        List<Res_CarData> ListData = new List<Res_CarData>();
                        for (int i = 0; i < dto.PageSize; i++)
                        {
                            var RowIndex = i + (dto.PageIndex - 1) * dto.PageSize;
                            if (RowIndex < CarData.Count)
                            {
                                ListData.Add(CarData[RowIndex]);
                            }
                            else
                            {
                                break;
                            }
                        }
                        return result = new Result()
                        {
                            Code = 0,
                            Msg = "查询成功",
                            Data = new { pageCount = count, totalPage = (int)totalPage, pageIndex = dto.PageIndex, pageSize = dto.PageSize, pageSource = ListData },
                        };
                    }
                    
                }
                else if (dto.PortType == 2)
                {
                    string sql = string.Format(@"select * from Res_CarData {0}", sqlWhere);
                    List<Res_CarData> CarData = await _sqlSugar.SqlQueryable<Res_CarData>(sql).ToListAsync();
                    if (CarData.Count == 0)
                    {
                        return result = new Result() { Code = -1, Msg = "暂无数据" };
                    }
                    CarData = CarData.OrderByDescending(x => x.CreateTime).ToList();

                    if (dto.PageSize == 0 || dto.PageIndex == 0)
                    {
                        return result = new Result()
                        {
                            Code = 0,
                            Msg = "查询成功",
                            Data = CarData,
                        };
                    }
                    else
                    {
                        int count = CarData.Count;
                        float totalPage = (float)count / dto.PageSize;//总页数
                        if (totalPage == 0) totalPage = 1;
                        else totalPage = (int)Math.Ceiling((double)totalPage);

                        List<Res_CarData> ListData = new List<Res_CarData>();
                        for (int i = 0; i < dto.PageSize; i++)
                        {
                            var RowIndex = i + (dto.PageIndex - 1) * dto.PageSize;
                            if (RowIndex < CarData.Count)
                            {
                                ListData.Add(CarData[RowIndex]);
                            }
                            else
                            {
                                break;
                            }
                        }
                        return result = new Result()
                        {
                            Code = 0,
                            Msg = "查询成功",
                            Data = new { pageCount = count, totalPage = ((int)totalPage).ToString(), pageIndex = dto.PageIndex, pageSize = dto.PageSize, pageSource = ListData },
                        };
                    }
                }
                else
                {
                    return result = new Result() { Code = -2, Msg = "请传入PortType参数！1:Web，2:Android,3:IOS" };
                }
            }
            catch (Exception)
            {
                return result;
                throw;
            }
            
        }
    }
}
